#
# spec file for package spacecmd
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2008-2018 Red Hat, Inc.
# Copyright (c) 2011 Aron Parsons <aronparsons@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! (0%{?fedora} || 0%{?rhel})
%if "%{_vendor}" == "debbuild"
%global __python /usr/bin/python3
%endif
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif

%if 0%{?fedora} || 0%{?suse_version} > 1320 || 0%{?rhel} >= 8 || "%{_vendor}" == "debbuild"
%global build_py3   1
%if "%{_vendor}" != "debbuild"
%global python_sitelib %{python3_sitelib}
%endif
%endif

%if 0%{?fedora} || 0%{?rhel} >= 8
%global python2prefix python2
%else
%global python2prefix python
%endif

Name:           spacecmd
Version:        5.0.12
Release:        150000.3.133.1
Summary:        Command-line interface to Spacewalk and Red Hat Satellite servers
License:        GPL-3.0-or-later
%if "%{_vendor}" == "debbuild"
Packager:       Uyuni packagers <devel@lists.uyuni-project.org>
Group:          admin
%else
Group:          Applications/System
%endif
URL:            https://github.com/uyuni-project/uyuni
Source: spacecmd-git-0.4ed1dac.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?fedora} || 0%{?rhel} || 0%{?suse_version} >= 1210 || "%{_vendor}" == "debbuild"
BuildArch:      noarch
%endif

BuildRequires:  make
%if "%{_vendor}" == "debbuild" || 0%{?rhel}
BuildRequires:  gettext
%endif
%if "%{_vendor}" == "debbuild"
BuildRequires:  intltool
%endif

%if 0%{?build_py3}
BuildRequires:  python3
%if "%{_vendor}" == "debbuild"
BuildRequires:  python3-dev
%else
BuildRequires:  python3-devel
BuildRequires:  python3-rpm-macros
%endif
Requires:       python3
Requires:       python3-dateutil
Requires:       python3-rpm
%else
BuildRequires:  %{python2prefix}
%if "%{_vendor}" == "debbuild"
BuildRequires:  %{python2prefix}-dev
%else
BuildRequires:  %{python2prefix}-devel
%endif
Requires:       %{python2prefix}-dateutil
Requires:       %{python2prefix}-simplejson
%if "%{_vendor}" == "debbuild"
Requires:       python-rpm
%else
Requires:       rpm-python
%endif
Requires:       %{python2prefix}
%if 0%{?suse_version}
BuildRequires:  python-xml
Requires:       python-xml
%endif
%endif
Requires:       file

%description
spacecmd is a command-line interface to Spacewalk and Red Hat Satellite servers

%prep
%setup -q -n spacecmd-git-0.4ed1dac

%build
# nothing to build

%install
%{__mkdir_p} %{buildroot}/%{_bindir}

%if 0%{?build_py3}
    sed -i 's|#!/usr/bin/python|#!/usr/bin/python3|' ./src/bin/spacecmd
%endif
%{__install} -p -m0755 src/bin/spacecmd %{buildroot}/%{_bindir}/

%{__mkdir_p} %{buildroot}/%{_sysconfdir}
touch %{buildroot}/%{_sysconfdir}/spacecmd.conf

%{__mkdir_p} %{buildroot}/%{_sysconfdir}/bash_completion.d
%{__install} -p -m0644 src/misc/spacecmd-bash-completion %{buildroot}/%{_sysconfdir}/bash_completion.d/spacecmd

%{__mkdir_p} %{buildroot}/%{python_sitelib}/spacecmd
%{__install} -p -m0644 src/spacecmd/*.py %{buildroot}/%{python_sitelib}/spacecmd/

%{__mkdir_p} %{buildroot}/%{_mandir}/man1
%{__gzip} -c src/doc/spacecmd.1 > %{buildroot}/%{_mandir}/man1/spacecmd.1.gz

touch %{buildroot}/%{python_sitelib}/spacecmd/__init__.py
%{__chmod} 0644 %{buildroot}/%{python_sitelib}/spacecmd/__init__.py

%if 0%{?suse_version}
%if 0%{?build_py3}
%py3_compile -O %{buildroot}/%{python_sitelib}
%else
%py_compile -O %{buildroot}/%{python_sitelib}
%endif
%endif

make -C po install PREFIX=$RPM_BUILD_ROOT
%find_lang spacecmd

%files -f spacecmd.lang
%defattr(-,root,root)
%{_bindir}/spacecmd
%{python_sitelib}/spacecmd/
%ghost %config %{_sysconfdir}/spacecmd.conf
%dir %{_sysconfdir}/bash_completion.d
%{_sysconfdir}/bash_completion.d/spacecmd
%doc src/doc/README src/doc/COPYING
%doc %{_mandir}/man1/spacecmd.1.gz

%changelog
* Tue Mar 11 2025 rosuna@suse.com
- version 5.0.12-0
  * Allow translation to wrap strings as weblate forces it
  * Show Source String change for translations
* Mon Jan 13 2025 rosuna@suse.com
- version 5.0.11-0
  * Update translation strings
* Thu Oct  3 2024 rosuna@suse.com
- version 5.0.10-0
  * Speed up softwarechannel_removepackages (bsc#1227606)
  * Fix error in 'kickstart_delete' when using wildcards
    (bsc#1227578)
  * Spacecmd bootstrap now works with specified port (bsc#1229437)
  * Fix sls backup creation as directory with spacecmd (bsc#1230745)
* Thu Aug  1 2024 marina.latini@suse.com
- version 5.0.9-0
  * Update translation strings
* Tue Jun 18 2024 marina.latini@suse.com
- version 5.0.8-0
  * Update translations
* Mon Jun 10 2024 marina.latini@suse.com
- version 5.0.7-0
  * Remove spacewalk-abrt related commands
* Fri May  3 2024 marina.latini@suse.com
- version 5.0.6-0
  * Update translations
* Thu Apr  4 2024 marina.latini@suse.com
- version 5.0.5-0
  * Update translation strings
* Tue Feb 13 2024 marina.latini@suse.com
- version 5.0.4-1
  * Update translation strings
* Mon Jan 29 2024 rosuna@suse.com
- version 5.0.3-1
  * Revert py2.7-incompatible formatting
* Mon Jan 29 2024 rosuna@suse.com
- version 5.0.2-1
  * Apply Black and Pylint to enforce Python style
* Tue Jan 16 2024 jgonzalez@suse.com
- version 5.0.1-1
  * Use localhost without ssl when running on the server
* Fri Dec 15 2023 rosuna@suse.com
- version 4.4.10-1
  * Update translation strings
* Wed Nov  1 2023 marina.latini@suse.com
- version 4.4.9-1
  * Update translation strings
* Mon Sep 18 2023 rosuna@suse.com
- version 4.4.8-1
  * Add spacecmd function: cryptokey_update
  * Update translation strings
  * Bypass traditional systems check on older SUMA instances (bsc#1208612)
  * fix argument parsing of distribution_update (bsc#1210458)
* Wed Apr 19 2023 marina.latini@suse.com
- version 4.4.7-1
  * remove pylint check at build time
  * Display activation key details after executing the corresponding command (bsc#1208719)
  * Show targetted packages before actually removing them (bsc#1207830)
* Tue Feb 21 2023 jgonzalez@suse.com
- version 4.4.6-1
  * Fix spacecmd not showing any output for softwarechannel_diff
    and softwarechannel_errata_diff (bsc#1207352)
* Mon Jan 23 2023 jgonzalez@suse.com
- version 4.4.5-1
  * Prevent string api parameters to be parsed as dates if not in
    ISO-8601 format (bsc#1205759)
  * Add python-dateutil dependency, required to process date values in
    spacecmd api calls
  * Remove python3-simplejson dependency
* Wed Dec 14 2022 jgonzalez@suse.com
- version 4.4.4-1
  * Correctly understand 'ssm' keyword on scap scheduling
  * Add vendor_advisory information to errata_details call (bsc#1205207)
  * Change default port of "Containerized Proxy configuration" 8022
* Fri Nov 18 2022 jgonzalez@suse.com
- version 4.4.3-1
  * Added two missing options to schedule product migration: allow-vendor-change
    and remove-products-without-successor (bsc#1204126)
  * Changed schedule product migration to use the correct API method
  * Fix dict_keys not supporting indexing in systems_setconfigchannelorger
  * Added a warning message for traditional stack deprecation
  * Remove "Undefined return code" from debug messages (bsc#1203283)
  * Update translation strings
* Thu Sep 29 2022 jgonzalez@suse.com
- version 4.4.2-1
  * Stop always showing help for valid proxy_container_config calls
* Wed Sep 28 2022 jgonzalez@suse.com
- version 4.4.1-1
  * Process date values in spacecmd api calls (bsc#1198903)
  * Improve Proxy FQDN hint message
* Wed Jul 27 2022 jgonzalez@suse.com
- version 4.3.14-1
  * Fix missing argument on system_listmigrationtargets (bsc#1201003)
  * Show correct help on calling kickstart_importjson with no arguments
  * Fix tracebacks on spacecmd kickstart_export (bsc#1200591)
  * Change proxy container config default filename to end with tar.gz
* Thu May 19 2022 jgonzalez@suse.com
- version 4.3.13-1
  * Update translation strings
* Fri May  6 2022 jgonzalez@suse.com
- version 4.3.12-1
  * Update translation strings
* Wed May  4 2022 jgonzalez@suse.com
- version 4.3.11-1
  * on full system update call schedulePackageUpdate API (bsc#1197507)
* Tue Apr 19 2022 jgonzalez@suse.com
- version 4.3.10-1
  * parse boolean paramaters correctly (bsc#1197689)
  * Add parameter to set containerized proxy SSH port
* Fri Mar 11 2022 jgonzalez@suse.com
- version 4.3.9-1
  * Add proxy config generation subcommand
* Fri Mar 11 2022 jgonzalez@suse.com
- version 4.3.8-1
  * implement system.bootstrap (bsc#1194909)
  * Option 'org_createfirst' added to perform initial organization and user creation
  * Added gettext build requirement for RHEL.
  * Removed RHEL 5 references.
* Tue Feb 15 2022 jgonzalez@suse.com
- version 4.3.7-1
  * Include group formulas configuration in spacecmd group_backup and
    spacecmd group_restore. This changes backup format to json,
    previously used plain text is still supported for reading (bsc#1190462)
  * Fix interactive mode for "system_applyerrata" and "errata_apply" (bsc#1194363)
* Mon Jan 24 2022 jgonzalez@suse.com
- version 4.3.6-1
  * Update translation strings
* Tue Jan 18 2022 jgonzalez@suse.com
- version 4.3.5-1
  * require python macros for building
* Tue Nov 16 2021 jgonzalez@suse.com
- version 4.3.4-1
  * Update translation strings
* Fri Nov  5 2021 jgonzalez@suse.com
- version 4.3.3-1
  * Improved event history listing and added new system_eventdetails
    command to retrieve the details of an event
  * configchannel_updatefile handles directory properly (bsc#1190512)
* Fri Sep 17 2021 jgonzalez@suse.com
- version 4.3.2-1
  * Add schedule_archivecompleted to mass archive actions (bsc#1181223)
  * Make schedule_deletearchived to get all actions without display limit
  * Allow passing a date limit for schedule_deletearchived on spacecmd (bsc#1181223)
  * Remove whoami from the list of unauthenticated commands (bsc#1188977)
* Mon Aug  9 2021 jgonzalez@suse.com
- version 4.3.1-1
- Use correct API endpoint in list_proxies (bsc#1188042)
- Add schedule_deletearchived to bulk delete archived actions (bsc#1181223)
- make spacecmd aware of retracted patches/packages
* Tue Jun  1 2021 jgonzalez@suse.com
- version 4.2.10-1
- enhance help for installation types when creating distributions (bsc#1186581)
* Mon May 24 2021 jgonzalez@suse.com
- version 4.2.9-1
- Parse empty argument when nothing in between the separator
* Wed May  5 2021 jgonzalez@suse.com
- version 4.2.8-1
- Rename system migration to system transfer
- Rename SP to product migration
* Mon Apr 19 2021 jgonzalez@suse.com
- version 4.2.7-1
- Update translation strings
* Fri Apr 16 2021 jgonzalez@suse.com
- version 4.2.6-1
- Add group_addconfigchannel and group_removeconfigchannel
- Add group_listconfigchannels and configchannel_listgroups
- Handle SIGPIPE without user-visible Exception (bsc#1181124)
- Fix spacecmd compat with Python 3
* Fri Feb 12 2021 jgonzalez@suse.com
- version 4.2.5-1
- Deprecated "Software Crashes" feature
- Document advanced package search on '--help' (bsc#1180583)
- Fixed advanced search on 'package_listinstalledsystems'
- Fixed duplicate results when using multiple search criteria (bsc#1180585)
* Wed Jan 27 2021 jgonzalez@suse.com
- version 4.2.4-1
- Fix spacecmd with no parameters produces traceback
  on SLE 11 SP4 (bsc#1176823)
- Fixed "non-advanced" package search when using multiple package names (bsc#1180584)
- Added '-r REVISION' option to the 'configchannel_updateinitsls' command (bsc#1179566)
- Fix: internal: workaround for future tee of logs translation
* Thu Dec  3 2020 jgonzalez@suse.com
- version 4.2.3-1
- Update translations
* Wed Nov 25 2020 jgonzalez@suse.com
- version 4.2.2-1
- Fix: make spacecmd build on Debian
- Python3 fixes for errata in spacecmd (bsc#1169664)
- Added support for i18n of user-facing strings
- Python3 fix for sorted usage (bsc#1167907)
* Fri Sep 18 2020 jgonzalez@suse.com
- version 4.2.1-1
- Fix softwarechannel_listlatestpackages throwing error on
  empty channels (bsc#1175889)
- Add Service Pack migration operations (bsc#1173557)
- Fix softwarechannel update for vendor channels (bsc#1172709)
- Update package version to 4.2.0
* Thu Jul 23 2020 jgonzalez@suse.com
- version 4.1.5-1
- fix escaping of package names (bsc#1171281)
* Wed Jun 10 2020 jgonzalez@suse.com
- version 4.1.4-1
- only report real error, not result (bsc#1171687)
- use defined return values for spacecmd methods so scripts can
  check for failure (bsc#1171687)
* Mon Feb 17 2020 jgonzalez@suse.com
- version 4.1.3-1
- disable globbing for api subcommand to allow wildcards in filter
  settings (bsc#1163871)
* Thu Jan 30 2020 jgonzalez@suse.com
- version 4.1.2-1
- Bugfix: attempt to purge SSM when it is empty (bsc#1155372)
* Wed Nov 27 2019 jgonzalez@suse.com
- version 4.1.1-1
- Bump version to 4.1.0 (bsc#1154940)
- Prevent error when piping stdout in Python 2 (bsc#1153090)
- Java api expects content as encoded string instead of encoded bytes like before (bsc#1153277)
- Enable building and installing for Ubuntu 16.04 and Ubuntu 18.04
- Fix building and installing on CentOS8/RES8/RHEL8
- Check that a channel doesn't have clones before deleting it (bsc#1138454)
- Add unit test for schedule, errata, user, utils, misc, configchannel
  and kickstart modules
- Multiple minor bugfixes alongside the unit tests
- Fix missing runtime dependencies that made spacecmd return old versions of
  packages in some cases, even if newer ones were available (bsc#1148311)
* Wed Jul 31 2019 jgonzalez@suse.com
- version 4.0.12-1
- Bugfix: referenced variable before assignment.
- Add unit test for report, package, org, repo and group
- Bugfix: 'dict' object has no attribute 'iteritems' (bsc#1135881)
- Add unit tests for custominfo, snippet, scap, ssm, cryptokey and distribution
* Wed May 15 2019 jgonzalez@suse.com
- version 4.0.11-1
- SPEC cleanup
* Mon Apr 22 2019 jgonzalez@suse.com
- version 4.0.10-1
- add unit tests for spacecmd.api, spacecmd.activationkey and spacecmd.filepreservation
- add unit tests for spacecmd.shell
- Save SSM list on system delete and update cache (bsc#1130077, bsc#1125744)
- add makefile and pylint configuration
* Mon Mar 25 2019 jgonzalez@suse.com
- version 4.0.9-1
- Add Pylint setup
- Replace iteritems with items for python2/3 compat (bsc#1129243)
* Mon Mar  4 2019 jgonzalez@suse.com
- version 4.0.8-1
- fix python 3 bytes issue when handling config channels
* Sat Mar  2 2019 jgonzalez@suse.com
- version 4.0.7-1
- Add '--force', '-f' option to regenerateYumCache (bsc#1127389)
* Wed Feb 27 2019 jgonzalez@suse.com
- version 4.0.6-1
- Prevent spacecmd crashing when piping the output in Python 3 (bsc#1125610)
* Thu Jan 31 2019 jgonzalez@suse.com
- version 4.0.5-1
- Fix compatibility with Python 3
* Wed Jan 16 2019 jgonzalez@suse.com
- version 4.0.4-1
- Fix importing state channels using configchannel_import
- Fix getting file info for latest revision (via configchannel_filedetails)
* Mon Dec 17 2018 jgonzalez@suse.com
- version 4.0.3-1
- Add function to merge errata and packages through spacecmd (bsc#987798)
- show group id on group_details (bsc#1111542)
- State channels handling: Existing commands configchannel_create and configchannel_import were updated
  while system_scheduleapplyconfigchannels and configchannel_updateinitsls were added.
* Fri Oct 26 2018 jgonzalez@suse.com
- version 4.0.2-1
- add summary to softwarechannel.clone when calling older API versions
  (bsc#1109023)
- New function/Update old functions to handle state channels as well
* Fri Aug 10 2018 jgonzalez@suse.com
- version 4.0.1-1
- Bump version to 4.0.0 (bsc#1104034)
- Fix copyright for the package specfile (bsc#1103696)
- Suggest not to use password option for spacecmd (bsc#1103090)
* Wed May 23 2018 jgonzalez@suse.com
- version 2.8.25.4-1
- add option to set cleanup type for system_delete (bsc#1094190)
* Wed May 16 2018 jgonzalez@suse.com
- version 2.8.25.3-1
- Sync with upstream (bsc#1083294)
* Mon Apr 23 2018 jgonzalez@suse.com
- version 2.8.25.2-1
- Sync with upstream (bsc#1083294)
- 1539878 - add save_cache to do_ssm_intersect
- Fix softwarechannel_listsyncschedule
* Wed Apr  4 2018 jgonzalez@suse.com
- version 2.8.21.2-1
- Disable pylint for python2 and RES < 8 (bsc#1088070)
* Mon Mar 26 2018 jgonzalez@suse.com
- version 2.8.21.1-1
- Sync with upstream (bsc#1083294)
- Connect to API using FQDN instead of hostname to avoid SSL
  validation problems (bsc#1085667)
* Mon Mar  5 2018 jgonzalez@suse.com
- version 2.8.20.1-1
- 1536484 - Command spacecmd supports utf8 name of systems
- 1484056 - updatefile and addfile are basically same calls
- 1484056 - make configchannel_addfile fully non-interactive
- 1445725 - display all checksum types, not just MD5
- remove clean section from spec (bsc#1083294)
- Added function to update software channel. Moreover, some
  refactoring has been done(bsc#1076578)
* Fri Feb 23 2018 jgonzalez@suse.com
- version 2.8.17.2-1
- add more python3 compatibility changes
* Fri Feb 23 2018 jgonzalez@suse.com
- version 2.8.17.1-1
- Compatibility with Python 3
- Fix typo (bsc#1081151)
- Configure gpg_flag via spacecmd creating a channel (bsc#1080290)
* Mon Feb  5 2018 jgonzalez@suse.com
- version 2.8.15.3-1
- Allow scheduling the change of software channels as an action.
  The previous channels remain accessible to the registered system
  until the action is executed.
  to the registered system until the action is executed.
* Fri Feb  2 2018 jgonzalez@suse.com
- version 2.8.15.2-1
- support multiple FQDNs per system (bsc#1063419)
* Wed Jan 17 2018 jgonzalez@suse.com
- version 2.8.13.2-1
- Fix bsc number for change 'configchannel export binary flag to
  json'
* Wed Jan 17 2018 jgonzalez@suse.com
- version 2.8.13.1-1
- add --config option to spacecmd
- Added custom JSON encoder in order to parse date fields correctly (bsc#1070372)
* Fri Nov 10 2017 mc@suse.de
- version 2.8.10.1-1
- pylint - fix intendation
* Thu Oct 26 2017 mc@suse.de
- version 2.8.9.1-1
- fix build with python 3
- show list of arches for channel
- allow softwarechannel_setsyncschedule to disable schedule
- add softwarechannel_setsyncschedule --latest
- in case of system named by id, let id take precedence
- Make spacecmd prompt for password when overriding config file user
- show less output of common packages in selected channels
- adding softwarechannel_listmanageablechannels
* Wed Aug 30 2017 mc@suse.de
- version 2.7.8.7-1
- Switched logging from warning to debug
* Tue Aug  8 2017 fkobzik@suse.de
- version 2.7.8.6-1
- configchannel export binary flag to json (bsc#1044719)
* Mon Jun 12 2017 mc@suse.de
- version 2.7.8.5-1
- spacecmd report_outofdatesystems: avoid one XMLRPC call per system
  (bsc#1015882)
* Mon May 29 2017 mc@suse.de
- version 2.7.8.4-1
- Remove debug logging from softwarechannel_sync function
* Tue May 23 2017 mc@suse.de
- version 2.7.8.3-1
- Remove get_certificateexpiration support in spacecmd (bsc#1013876)
* Wed May  3 2017 michele.bologna@suse.com
- version 2.7.8.2-1
- Adding softwarechannel_listmanageablechannels
* Mon Apr  3 2017 mc@suse.de
- version 2.7.8.1-1
- fix syntax error
* Fri Mar 31 2017 mc@suse.de
- version 2.7.7.1-1
- make sure to know if we get into default function and exit
  accordingly
* Tue Mar  7 2017 mc@suse.de
- version 2.7.6.1-1
- exit with 1 with incorrect command, wrong server, etc.
- Updated links to github in spec files
- print also systemdid with system name
- improve output on error for listrepo (bsc#1027426)
- print profile_name instead of string we're searching for
- Fix: reword spacecmd removal msg (bsc#1024406)
- Fix interactive mode
- Add a type parameter to repo_create
* Tue Feb  7 2017 michele.bologna@suse.com
- version 2.7.3.2-1
- Removed obsolete code (bsc#1013938)
* Wed Jan 11 2017 michele.bologna@suse.com
- version 2.7.3.1-1
- Version 2.7.3-1
* Mon Nov  7 2016 michele.bologna@suse.com
- version 2.5.5.3-1
- Make exception class more generic and code fixup (bsc#1003449)
- Handle exceptions raised by listChannels (bsc#1003449)
- Alert if a non-unique package ID is detected
* Tue May 24 2016 kwalter@suse.com
- version 2.5.5.2-1
- make spacecmd createRepo compatible with SUSE Manager 2.1 API
  (bsc#977264)
* Wed Feb 10 2016 mc@suse.de
- version 2.5.5.1-1
- mimetype detection to set the binary flag requires 'file' tool
- Text description missing for remote command by Spacecmd
* Tue Jan 26 2016 mc@suse.de
- version 2.5.2.1-1
- spacecmd: repo_details show 'None' if repository doesn't have SSL
  Certtificate
- spacecmd: Added functions to add/edit SSL certificates for
  repositories
* Tue Jan  5 2016 mc@suse.de
- version 2.5.1.2-1
- build spacecmd noarch only on new systems
* Mon Nov 30 2015 mc@suse.de
- version 2.5.1.1-1
- mimetype detection to set the binary flag requires 'file' tool
- fix export/cloning: always base64
- Always base64 encode to avoid trim() bugs in the XML-RPC library.
* Thu Nov 19 2015 dmacvicar@suse.de
- set binary mode on uploaded files based on content
  (bsc#948245)
* Wed Oct  7 2015 mc@suse.de
- version 2.5.0.1-1
- drop monitoring
- replace upstream subscription counting with new subscription
  matching (FATE#311619)
* Wed Sep 23 2015 mc@suse.de
- version 2.1.25.10-1
- Revert "1207606 - do not return one package multiple times" (bsc#945380)
- check for existence of device description in spacecmd system_listhardware
  (bsc#932288)
* Mon Jun 22 2015 jrenner@suse.de
- version 2.1.25.9-1
- do not escape spacecmd command arguments
- do not return one package multiple times
- add system_setcontactmethod (FATE#314858)
- add activationkey_setcontactmethod (FATE#314858)
- show contact method with activationkey_details and system_details
- clone config files without loosing trailing new lines (bsc#926318)
* Tue Mar 31 2015 mc@suse.de
- version 2.1.25.8-1
- sanitize data from export
* Thu Jan 29 2015 mc@suse.de
- version 2.1.25.7-1
- fix configchannel export - do not create 'contents' key for directories
  (bsc#908849)
- fix patch summary printing
- code cleanup
- add new function kickstart_getsoftwaredetails
- Added feature to get installed packageversion of a system or systems managed
  by ssm to spacecmd
* Thu Dec  4 2014 mc@suse.de
- version 2.1.25.6-1
- call listAutoinstallableChannels() for listing distributions
  (bsc#887879)
- Fix spacecmd schedule listing (bsc#902494)
- Teach spacecmd report_errata to process all-errata in the absence
  of further args
* Tue Dec  2 2014 mc@suse.de
- fix call of setCustomOptions() during kickstart_importjson
  (bsc#879904)
* Fri Nov  7 2014 mc@suse.de
- version 2.1.25.5-1
- spacecmd: fix listupgrades [bnc#892707]
* Fri Aug  1 2014 mc@suse.de
- version 2.1.25.4-1
- make print_result a static method of SpacewalkShell (bnc#889605)
* Tue Jun 17 2014 jrenner@suse.de
- version 2.1.25.3-1
- Added option to force deployment of a config channel to all subscribed systems
- Added last boot message in system_details command
- Updated kickstart_import documentation
- Added kickstart_import_raw command
* Tue May  6 2014 mc@suse.de
- version 2.1.25.2-1
- set output encoding when stdout is not a tty
* Thu Feb 27 2014 fcastelli@suse.com
- version 2.1.25.1-1
- make file_needs_b64_enc work for both str and unicode inputs
* Thu Feb 13 2014 mc@suse.de
- version 2.1.24.1-1
- Updating the copyright years info
* Mon Jan 13 2014 mc@suse.de
- version 2.1.22.1-1
- fix spacecmd, so it does not expect package id within the
  system.listPackages API call
- fix binary file detection
- added function package_listdependencies
* Wed Dec 18 2013 mc@suse.de
- version 2.1.20.1-1
- don't attempt to write out 'None'
- fix system listing when identified by system id
* Mon Dec  9 2013 mc@suse.de
- version 2.1.18.1-1
- switch to 2.1
* Wed Aug 21 2013 mc@suse.de
- version 1.7.7.11-1
- fixing spacecmd ssm 'list' has no attribute 'keys' error
* Wed Jun 12 2013 mc@suse.de
- version 1.7.7.10-1
- spacecmd errors out when trying to add script to kickstart
- Make spacecmd able to specify config channel label
* Thu Apr  4 2013 mc@suse.de
- version 1.7.7.9-1
- fix directory export in configchannel_export
- use 755 as default permissions for directories in
  configfile_getinfo
- fix directory creation in configchannel_addfile
- print the list of systems in system_runscript
- print the list of systems in system_reboot
- return a unique set from expand_systems
- print a clearer error message when duplicate system names are found
- standardize the behavior for when a system ID is not returned
- add a delay before regenerating the system cache after a delete
- handle binary files correctly in configfile_getinfo
- print the name in the confirmation message of snippet_create
- don't reuse variable names in parse_arguments
- print the function's help message when -h in the argument list
- print file path in package_details
- fixing broken export of configchannels with symlinks
* Fri Sep 28 2012 mc@suse.de
- version 1.7.7.8-1
- prevent outputting escape sequences to non-terminals
- Fixed small typo in spacecmd/src/lib/kickstart.py
- do not quote argument of the help command (bnc#776615)
* Mon Jul 16 2012 ug@suse.de
- version 1.7.7.7-1
- Fix kickstart_export with old API versions
* Fri Jul  6 2012 ug@suse.de
- command line parameter for "distribution path" was
  documented wrong in help text
  (bnc#769106)
* Thu Jul  5 2012 ug@suse.de
- "suse" was missing in the helptext of the CLI for
  distributions (bnc#769108)
* Mon Jun 25 2012 mc@suse.de
- version 1.7.7.6-1
- enhancement add configchannel_sync
- enhancement add softwarechannel_sync
* Thu Jun 21 2012 jrenner@suse.de
- version 1.7.7.5-1
- fixing chroot option for addscript
* Thu May 31 2012 mc@suse.de
- version 1.7.7.4-1
- kickstart_getcontents fix character encoding error
- activationkey_import don't add empty package/group lists
- fix activationkey_import when no base-channel specified
- Fix reference to non-existent variable
- improve configchannel_export operation on old API versions
- *diff functions allow python 2.4 compatibility
- changed get_string_diff_dicts to better fitting replacement method
- remove reference to stage function
- add do_SPACEWALKCOMPONENT_diff functions
- system_comparewithchannel filter system packagelist
- argument validation needed for configchannel_addfile
- configchannel_addfile don't display b64 file contents
* Fri Apr 27 2012 mc@suse.de
- version 1.7.7.3-1
- enhancement add system_addconfigfile
- Fix usage for configchannel_addfile
- enhancement Add system_listconfigfiles
- add option to allow templating for spacecmd kickstarting
* Fri Mar 30 2012 mc@suse.de
- version 1.7.7.2-1
- softwarechannel_clone avoid ISE on duplicate name
- softwarechannel_adderrata mergeErrata should be
  cloneErrataAsOriginal
- Add globbing support to distribution_details
- Add globbing support to distribution_delete
- Cleanup some typos in comments
- custominfo_details add support for globbing key names
- custominfo_deletekey add support for globbing key names
- Add cryptokey_details globbing support
- cryptokey_delete add support for globbing
- Workaround missing date key in recent spacewalk listErrata
- Add validation to softwarechannel_adderrata channel args
- softwarechannel_adderrata add --skip mode
- Add --quick mode to softwarechannel_adderrata
- Allow config-channel export of b64 encoded files
- Update the spacecmd copyright years
* Wed Mar 21 2012 mc@suse.de
- version 1.7.7.1-1
- Bumping package version
* Fri Feb 11 2011 mantel@suse.de
- debranding
* Sun Jan 30 2011 mc@suse.de
- backport upstrem fixes
* Wed Sep 15 2010 mantel@suse.de
- Initial release of spacecmd
